@@ -1,10 +1,11 @@
 import unittest
 
+
 def setUpModule():
     raise ValueError("This is an INTENTIONAL value error in setUpModule.")
 
+
 class SetUpModuleTest(unittest.TestCase):
-    
     def setUp(cls):
         pass
 
@@ -12,5 +13,5 @@ class SetUpModuleTest(unittest.TestCase):
         pass
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     unittest.main()
